unit BDEUserControl;

interface

uses
  SysUtils, Classes, UCDefine, UCConsts, UCMessages, DBTables, DB,
  Dialogs, Menus, ActnList;

type
  TBDEUserControl = class(TUCDefine)
  private
    FDatabase : TDatabase;
    procedure SetBDEDatabase(Value : TDatabase);
    function BDEGetQuery: TQuery;
    function BDEExistTable(Tabela: String): Boolean;

  protected
    procedure CriaCadUserForm;override;
    procedure CriaProfileUserForm;override;
    procedure ActionLog(Sender : TObject); override;
    procedure ActionBtPermiss(Sender : TObject);override;
    procedure ActionBtPermissProfile(Sender: TObject);override;
    procedure Notification(AComponent: TComponent; Operation: TOperation);override;
    procedure UCExecSQL(FSQL: String);override;
    function UCGetSQLDataset(FSQL : String) : TDataset;override;
    function UCFindTable(const Tablename : String) : Boolean; override;
    function UCFindDataConnection : Boolean; override;
  public
    property CurrentUser;
  published
    property Database : TDatabase read FDatabase write SetBDEDatabase;
  end;



procedure Register;

implementation

uses UserPermis_U, CadUser_U, CadPerfil_U, TrocaSenha_U, LoginWindow_U,
  ViewLog_U;

{ TBDEUserControl }


procedure TBDEUserControl.ActionBtPermiss(Sender: TObject);
begin
  inherited;
  UserPermis.TempIdUser := TCadUser(FormCadastroUsuarios).DSCadUser.FieldByName('IdUser').asInteger;

  UserPermis.DSPermiss := UCGetSQLDataset('Select * from ' + TableRights + ' Where IdUser = ' + TCadUser(FormCadastroUsuarios).DSCadUser.FieldByName('IdUser').asString + ' and Modulo = ' + QuotedStr(ApplicationID));
  UserPermis.DSPermiss.Open;

  UserPermis.DSCmd := BDEGetQuery;

  UserPermis.DSPerfil := UCGetSQLDataset('Select * from ' + TableRights + ' Where IdUser = ' + IntToStr(TCadUser(FormCadastroUsuarios).DSCadUser.FieldByName('Perfil').asInteger) + ' and Modulo = ' + QuotedStr(ApplicationID));
  UserPermis.DSPerfil.Open;

  UserPermis.ShowModal;
  FreeAndNil(UserPermis);
end;

procedure TBDEUserControl.ActionBtPermissProfile(Sender: TObject);
begin
  inherited;
  UserPermis.TempIdUser := TCadPerfil(FormPerfilUsuarios).DSPerfilUser.FieldByName('IdUser').asInteger;

  UserPermis.DSPermiss := UCGetSQLDataset('Select * from ' + TableRights + ' Where IdUser = ' + TCadPerfil(FormPerfilUsuarios).DSPerfilUser.FieldByName('IdUser').asString + ' and Modulo = ' + QuotedStr(ApplicationID));
  UserPermis.DSPermiss.Open;

  UserPermis.DSCmd := BDEGetQuery;

  UserPermis.DSPerfil := TDataset.Create(nil);

  UserPermis.ShowModal;
  FreeAndNil(UserPermis);
end;

procedure TBDEUserControl.CriaCadUserForm;
begin
  inherited;
  TCadUser(FormCadastroUsuarios).DSCadUser := UCGetSQLDataset('Select * from '+ FTabelaUsuarios+ ' Where Tipo = '+QuotedStr('U')+' ORDER BY Login');
  TCadUser(FormCadastroUsuarios).DSCadUser.Open;
  TCadUser(FormCadastroUsuarios).DBGrid1.Columns[0].Title.Caption := Settings.UsersForm.ColName;
  TCadUser(FormCadastroUsuarios).DBGrid1.Columns[1].Title.Caption := Settings.UsersForm.ColLogin;
  TCadUser(FormCadastroUsuarios).DBGrid1.Columns[2].Title.Caption := Settings.UsersForm.ColEmail;

  TCadUser(FormCadastroUsuarios).DScmd := BDEGetQuery;

  TCadUser(FormCadastroUsuarios).DSPerfilUser := UCGetSQLDataset('Select * from '+ FTabelaUsuarios+ ' Where Tipo = '+QuotedStr('P')+' ORDER BY Nome');
  TCadUser(FormCadastroUsuarios).DSPerfilUser.Open;
end;

procedure TBDEUserControl.CriaProfileUserForm;
begin
  inherited;
  TCadPerfil(FormPerfilUsuarios).DSPerfilUser := UCGetSQLDataset('Select * from '+ FTabelaUsuarios +' Where Tipo = '+QuotedStr('P'));
  TCadPerfil(FormPerfilUsuarios).DSPerfilUser.Open;
  TCadPerfil(FormPerfilUsuarios).DBGrid1.Columns[0].Title.Caption := Settings.UsersProfile.ColProfile;

  TCadPerfil(FormPerfilUsuarios).DSCmd := BDEGetQuery;

end;

procedure Register;
begin
  RegisterComponents('User Control', [TBDEUserControl]);
end;


procedure TBDEUserControl.Notification(AComponent: TComponent;
  Operation: TOperation);
begin
  if (Operation = opRemove) and (AComponent = FDatabase) then
  begin
    FDatabase := nil;
  end;
  inherited Notification(AComponent, Operation);
end;

procedure TBDEUserControl.ActionLog(Sender: TObject);
begin
  inherited;
  TViewLog(FormLogControl).DSLog := BDEGetQuery;
  TViewLog(FormLogControl).DSCmd := BDEGetQuery;
  FormLogControl.ShowModal;
  FreeandNil(FormLogControl);
end;

function TBDEUserControl.BDEGetQuery : TQuery;
var
  FQuery: TQuery;
begin
  FQuery := TQuery.Create(nil);
  FQuery.DatabaseName := FDatabase.DatabaseName;
  FQuery.RequestLive := True;
  Result := FQuery;
end;

procedure TBDEUserControl.UCExecSQL(FSQL: String);
begin
  with BDEGetQuery do
  begin
    SQL.Text := FSQL;
    ExecSQL;
    Free;
  end;
end;


function TBDEUserControl.UCGetSQLDataset(FSQL: String): TDataset;
begin
  Result := BDEGetQuery;
  with Result as TQuery do
  begin
    SQL.text := FSQL;
    Open;
  end;
end;

procedure TBDEUserControl.SetBDEDatabase(Value: TDatabase);
begin
  if FDatabase <> Value then FDatabase := Value;
  if FDatabase <> nil then FDatabase.FreeNotification(Self);

end;


function TBDEUserControl.BDEExistTable(Tabela: String): Boolean;
var
  Lista : TStringList;
begin
  Lista := TStringList.Create;
{$IFDEF VER130}
   FDatabase.Session.GetTableNames(FDatabase.Databasename,'*.db*', False, False, Lista);
{$ELSE}
  FDatabase.GetTableNames(Lista);
{$ENDIF}
  Result := Lista.IndexOf(Tabela) > -1;
  FreeAndNil(Lista);
end;

function TBDEUserControl.UCFindDataConnection: Boolean;
begin
  Result := Assigned(FDatabase);
end;

function TBDEUserControl.UCFindTable(const Tablename: String): Boolean;
begin
  Result := BDEExistTable(TableName);
end;

end.
